// Define the pin numbers
const int buttonPin = 0; // PA4 on ATtiny1614 corresponds to physical pin number as per `megaTinyCore`
const int ledPin = 3; // Use built-in LED to indicate button press (optional)

void setup() {
  // Initialize serial communication at 9600 baud rate
  Serial.begin(9600);
  
  // Configure buttonPin as an input with internal pull-up resistor
  pinMode(buttonPin, INPUT);
  
  // Configure ledPin as an output (optional)
  pinMode(ledPin, OUTPUT);
}

void loop() {
  // Check if the button is pressed
  // Note: The button is configured with an internal pull-up resistor,
  // so pressing the button will pull the pin LOW.
  if (digitalRead(buttonPin) == LOW) {
    // Debounce delay
    delay(50); // Simple software debounce

    // Check if the button is still pressed after debounce delay
    if (digitalRead(buttonPin) == LOW) {
      // Send a simple signal (e.g., a byte) to indicate a button press
      Serial.write('1'); // Sending ASCII character '1'
      
      // Turn the LED on (optional)ji,j.
      digitalWrite(ledPin, HIGH);
      
      // Wait until the button is released to avoid repeating the signal
      while (digitalRead(buttonPin) == LOW);
      
      // Turn the LED off (optional)
      digitalWrite(ledPin, LOW);
      
      // Optional: additional delay to prevent bouncing effects
      delay(50);
    }
  }
}
